@@ -4,8 +4,8 @@ import torch
 from torch import tensor
 from dl2050utils.core import listify
 import matplotlib.pyplot as plt
-from nn2.etc import *
-from nn2.cbs import *
+from dl2050nn.etc import *
+from dl2050nn.cbs import *
 
 
 def merge(os, dest, f):
